# AlmaxClasses
Generic Purpose Classes

# AlmaxGraphics
Everything i use to create graphics for Desktop apps or other needs

# AlmaxLogs
Logging services

# AlmaxSystemManagment
Some Utils you can use to manage Subprocesses or Threads

# AlmaxUtils
Utility functions for any purpose